#
# spec file for package deepin-network-utils
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name dde-network-utils
%define sover 1
%define gtest_version    %(rpm -q --queryformat '%%{VERSION}' gtest)

Name:           deepin-network-utils
Version:        5.4.13
Release:        2.3
License:        GPL-3.0-or-later
Summary:        Deepin Network Utils
Group:          Productivity/Networking/System
URL:            https://github.com/linuxdeepin/dde-network-utils
Source:         https://github.com/linuxdeepin/dde-network-utils/archive/%{version}/%{_name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gtest
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(gio-qt)
BuildRequires:  pkgconfig(gsettings-qt)

%description
Deepin Network Utils is an application repackage the DBus data which is provided
by network module of dde-daemon

%package -n lib%{_name}%{sover}
Summary:        Deepin Network Utils libraries
Group:          System/Libraries
Recommends:     %{name}-lang

%description -n lib%{_name}%{sover}
The  package contains the Libraries for deepin-network-utils.

%package devel
Summary:        Development tools for Deepin Network Utils
Group:          Development/Libraries/C and C++
Requires:       lib%{_name}%{sover} = %{version}-%{release}

%description devel
The deepin-network-utils-devel package contains the header files for
deepin-network-utils.

%lang_package

%prep
%setup -q -n %{_name}-%{version}
sed -i "s/lrelease/lrelease-qt5/g" translate_generation.sh
sed -i 's|$$PREFIX/lib|$$LIBDIR|g' dde-network-utils/dde-network-utils.pro
%if "%{gtest_version}" >= "1.14.0"
sed -i "s/c++11/c++14/g" tests/dde-network-utils/tst_dde-network-utils.pro
%endif

%build
%qmake5 PREFIX=%{_prefix} LIBDIR=%{_libdir}
%make_build

%install
%qmake5_install
%find_lang %{_name} --with-qt

%post -n lib%{_name}%{sover}
/sbin/ldconfig

%postun -n lib%{_name}%{sover}
/sbin/ldconfig

# Please do not drop main package, the language package forcedly depends the main package
%files
%defattr(-,root,root)
%doc README.md CHANGELOG.md
%license LICENSE

%files -n lib%{_name}%{sover}
%{_libdir}/lib%{_name}.so.*

%files lang -f %{_name}.lang
%dir %{_datadir}/%{_name}
%dir %{_datadir}/%{_name}/translations
%{_datadir}/%{_name}/translations/dde-network-utils.qm
# unusual languages, currently not correctly detected by find_lang
%lang(ast) %{_datadir}/%{_name}/translations/dde-network-utils_ast.qm
%lang(kab) %{_datadir}/%{_name}/translations/dde-network-utils_kab.qm
%lang(pam) %{_datadir}/%{_name}/translations/dde-network-utils_pam.qm

%files devel
%license LICENSE
%doc README.md CHANGELOG.md
%{_includedir}/libddenetworkutils
%{_libdir}/lib%{_name}.so
%{_libdir}/pkgconfig/%{_name}.pc

%changelog
* Thu Mar 28 2024 Hillwood Yang <hillwood@opensuse.org>
- Fix build on gtest 1.14.0
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.13
  * Fix a bug
* Tue Nov  9 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.12
  * Change interface name for LAN
  * Fix bug for DSL
* Mon Jul 26 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.9
  * Fix bugs
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.4.6
  * Fix compiler warnings
- Use find_lang macro
* Tue May  4 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.5
  * Configure ci rule
  * Update translations
  * Fix bugs
* Mon Feb 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.0.8
  * Fix bugs
  * Change apis
* Tue Dec 10 2019 Hillwood Yang <hillwoodroc@gmail.com>
- Update version to 5.0.1
  * Update translations.
* Tue Apr 16 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.1.4
  * Fix connectivity allways NotFull if startup without NotFull
  * Check network connectivity
  * Distribute active connections to devices
  * There could be multiple active connections for a device
  * Fix macaddress
* Wed Jan  9 2019 hillwood@opensuse.org
- Initial package for version  0.0.8.2
